@@ -1128,3 +1128,70 @@ HifiStrikesVolSurface = """
       }
     }
 """
+
+
+HifiVolSurfaceStrikesGreeksMinute = """
+query HifiVolSurfaceStrikesGreeksMinute(
+  $symbol: BTCOrETHEnumType, 
+  $dateTime: String, 
+  $exchange: ExchangeEnumType
+   ){
+  HifiVolSurfaceStrikesGreeksMinute(
+    symbol: $symbol, 
+    dateTime: $dateTime, 
+    exchange:$exchange,
+    ) {
+    date
+    currency
+    expiration
+    strike
+    putCall
+    spot
+    underlyingPrice
+    bidIv
+    markIv
+    askIv
+    bestBidAmount
+    bestBidPrice
+    markPrice
+    bestAskPrice
+    bestAskAmount
+    delta
+    gamma
+    vega
+  } 
+}
+"""
+
+HifiVolSurfaceStrikesGreeksHourly = """
+query HifiVolSurfaceStrikesGreeksHourly(
+  $symbol: BTCOrETHEnumType, 
+  $date: String, 
+ $interval:String,
+$exchange: ExchangeEnumType ){
+  HifiVolSurfaceStrikesGreeksHourly(
+    symbol: $symbol, 
+    date: $date, 
+    interval: $interval, 
+    exchange:$exchange) {
+    date
+    currency
+    expiration
+    strike
+    putCall
+    spot
+    underlyingPrice
+    bidIv
+    markIv
+    askIv
+    bestBidAmount
+    bestBidPrice
+    markPrice
+    bestAskPrice
+    bestAskAmount
+    delta
+    gamma
+    vega
+  } 
+}
+"""
